@@ -152,35 +152,37 @@ class TcSoaBasics:
 
     @classmethod
     def getPropString(cls, bo: BusinessObject, prop_name: str):
-        return cls.getPropStringList(bo, prop_name)[0]
+        lst = cls.getPropStringList(bo, prop_name)
+        return lst[0] if lst else None
 
     @classmethod
     def getPropStringList(cls, bo: BusinessObject, prop_name: str):
         return cls.getProperties([bo], [prop_name])[bo['uid']]['props'][prop_name]['uiValues']
 
     @classmethod
-    def getMultiPropStringList(cls, bos: List[BusinessObject], prop_name: str):
+    def getMultiPropStringList(cls, bos: List[BusinessObject], prop_name: str) -> Dict[str, List[str]]:
         return {uid: obj.prop(prop_name) for uid, obj in cls.getProperties(bos, [prop_name]).items()}
 
     @classmethod
-    def getMultiPropString(cls, bos: List[BusinessObject], prop_name: str):
+    def getMultiPropString(cls, bos: List[BusinessObject], prop_name: str) -> Dict[str, str]:
         return {uid: val_list[0] for uid, val_list in cls.getMultiPropStringList(bos, prop_name).items()}
 
     @classmethod
-    def getPropObject(cls, bo: BusinessObject, prop_name: str):
-        return cls.getPropObjectList(bo, prop_name)[0]
+    def getPropObject(cls, bo: BusinessObject, prop_name: str) -> BusinessObject:
+        lst = cls.getPropObjectList(bo, prop_name)
+        return lst[0] if lst else None
 
     @classmethod
-    def getPropObjectList(cls, bo: BusinessObject, prop_name: str):
+    def getPropObjectList(cls, bo: BusinessObject, prop_name: str) -> List[BusinessObject]:
         response: ServiceData = DataManagementService().getProperties(
             objects=[bo],
             attributes=[prop_name],
         )
         ref_obj_uids = response.modelObjects[bo.uid].prop(prop_name, db_value=True)
-        return [response.modelObjects[uid] for uid in ref_obj_uids]
+        return [response.modelObjects[uid] for uid in ref_obj_uids if uid]
 
     @classmethod
-    def getMultiPropObjectList(cls, bos: List[BusinessObject], prop_name: str):
+    def getMultiPropObjectList(cls, bos: List[BusinessObject], prop_name: str) -> Dict[str, List[BusinessObject]]:
         response = DataManagementService().getProperties(
             objects=bos,
             attributes=[prop_name],
@@ -189,7 +191,7 @@ class TcSoaBasics:
         return {uid: [response.modelObjects[ref] for ref in refs if ref] for uid, refs in obj2refs_map.items()}
 
     @classmethod
-    def getMultiPropObject(cls, bos: List[BusinessObject], prop_name: str):
+    def getMultiPropObject(cls, bos: List[BusinessObject], prop_name: str) -> Dict[str, BusinessObject]:
         return {uid: val_list[0] for uid, val_list in cls.getMultiPropObjectList(bos, prop_name).items()}
 
     @classmethod
