@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from tcsoa.gen.AWS2._2018_12.RequirementsManagement import CreateTracelinksResponse, CreateTracelinksInputData
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class RequirementsManagementService(TcService):
