@@ -1,5 +1,5 @@
 from tcsoa.gen.ActiveWorkspaceBom._2015_10.services import OccurrenceManagementCadService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class OccurrenceManagementCadService(TcService):
