@@ -4,7 +4,7 @@ from tcsoa.gen.AuthorizedDataAccess._2017_05.services import LicenseManagementSe
 from tcsoa.gen.AuthorizedDataAccess._2013_05.services import LicenseManagementService as imp3
 from tcsoa.gen.AuthorizedDataAccess._2018_06.services import LicenseManagementService as imp4
 from tcsoa.gen.AuthorizedDataAccess._2012_09.services import LicenseManagementService as imp5
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class LicenseManagementService(TcService):
