@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import POM_object, Cfg0AbsAdmissibility, Cfg0ConfiguratorPerspective
+from tcsoa.gen.BusinessObjects import Cfg0AbsAdmissibility, POM_object, Cfg0ConfiguratorPerspective
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
