@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import POM_object, BusinessObject, PSBOMViewRevision
+from tcsoa.gen.BusinessObjects import BusinessObject, POM_object, PSBOMViewRevision
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
