@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_CodeCoverage._2011_06.services import CodeCoverageManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class CodeCoverageManagementService(TcService):
