@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from tcsoa.gen.Internal.Notification._2014_10.SubscriptionManagement import GetSubscriptionConditionsResponse
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SubscriptionManagementService(TcService):
