@@ -1,8 +1,8 @@
 from __future__ import annotations
 
 from tcsoa.gen.Server import ServiceData
-from tcsoa.gen.Internal.ProductConfiguratorAw._2020_12.ConfiguratorManagement import VariantExpressionDataResponse2, ValidateProductConfigsResponse2, VariantExpressionDataInput2, SetVariantExpressionDataInput, VariantConfigurationViewResponse2, VariantConfigurationViewIn2, ValidateProductConfigsInput
-from tcsoa.utils import TcService
+from tcsoa.gen.Internal.ProductConfiguratorAw._2020_12.ConfiguratorManagement import SetVariantExpressionDataInput, ValidateProductConfigsInput, VariantConfigurationViewResponse2, VariantConfigurationViewIn2, VariantExpressionDataInput2, VariantExpressionDataResponse2, ValidateProductConfigsResponse2
+from tcsoa.base import TcService
 
 
 class ConfiguratorManagementService(TcService):
