@@ -4,7 +4,7 @@ from tcsoa.gen.BusinessObjects import BusinessObject, WorkspaceObject
 from enum import Enum
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 from datetime import datetime
 
